+++
title = "Org TODO keywords with double-underscores"
description = """
  This feature that replaces double-underscores in Org TODO keywords
  with spaces was added in commit [7691f0453b](https://github.com/kaushalmodi/ox-hugo/commit/7691f0453b).
  """
tags = ["todo", "double-underscores", "space"]
draft = false
+++

## <span class="org-todo todo TEST__TODO">TEST TODO</span> This heading's TODO kwd should read as "TEST TODO" {#this-heading-s-todo-kwd-should-read-as-test-todo}


## <span class="org-todo done TEST__DONE">TEST DONE</span> This heading's TODO kwd should read as "TEST DONE" {#this-heading-s-todo-kwd-should-read-as-test-done}
